@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyappfilechooser.c 12842 2011-09-12 09:47:28Z yeti-dn $
+ *  @(#) $Id: gwyappfilechooser.c 13256 2011-12-20 12:32:52Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -673,7 +673,7 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
                                       &setting);
     button = gtk_toggle_button_new();
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), setting);
-    gtk_widget_set_can_focus(button, FALSE);
+    GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
     gtk_tooltips_set_tip(tips, button,
                          _("Plane-level previewed data"), NULL);
@@ -689,7 +689,7 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
                                       &setting);
     button = gtk_toggle_button_new();
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), setting);
-    gtk_widget_set_can_focus(button, FALSE);
+    GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
     gtk_tooltips_set_tip(tips, button,
                          _("Row-level previewed data"), NULL);
