@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyddion.c 12593 2011-07-13 19:24:09Z yeti-dn $
+ *  @(#) $Id: gwyddion.c 13249 2011-12-19 13:24:24Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -412,7 +412,7 @@ setup_logging(void)
         "GLib", "GLib-GObject", "GLib-GIO", "GModule", "GThread",
         "GdkPixbuf", "Gdk", "Gtk",
         "GdkGLExt", "GtkGLExt",
-        "Pango",
+        "Pango", "Unique",
         "Gwyddion", "GwyProcess", "GwyDraw", "Gwydgets", "GwyModule", "GwyApp",
         "Module", NULL
     };
