@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwystock.h 12576 2011-07-11 14:51:57Z yeti-dn $
+ *  @(#) $Id: gwystock.h 13351 2012-03-29 09:23:12Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -21,7 +21,7 @@
 #ifndef __GWY_STOCK_H__
 #define __GWY_STOCK_H__
 
-#include <glib/gmacros.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
