@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwytiff.h 13351 2012-03-29 09:23:12Z yeti-dn $
+ *  @(#) $Id: gwytiff.h 13464 2012-05-16 21:26:08Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -722,7 +722,7 @@ gwy_tiff_get_image_reader(const GwyTIFF *tiff,
     g_free(bps);
 
     /* The TIFF specs say this is required, but it seems to default to
-     * MAXINT.  Setting more reasonably to RowsPerStrip = ImageLength achieves
+     * MAXINT.  Setting more reasonably RowsPerStrip = ImageLength achieves
      * the same ends. */
     if (!gwy_tiff_get_uint(tiff, dirno, GWY_TIFFTAG_ROWS_PER_STRIP,
                            &reader.strip_rows))
@@ -761,11 +761,12 @@ gwy_tiff_get_image_reader(const GwyTIFF *tiff,
         return NULL;
     }
 
-    /* Seen in Carl Zeiss SEM files. */
-    if (reader.strip_rows == (guint)-1)
+    /* Apparently in Zeiss SEM files, RowsPerStrip can be *anything* larger
+     * than the imager height. */
+    if (reader.strip_rows > reader.height)
         reader.strip_rows = reader.height;
 
-    if (reader.strip_rows == 0 || reader.strip_rows > reader.height) {
+    if (reader.strip_rows == 0) {
         err_INVALID(error, "RowsPerStrip");
         return NULL;
     }
