@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: nanoscope.c 13030 2011-11-12 10:21:28Z yeti-dn $
+ *  @(#) $Id: nanoscope.c 13295 2012-02-09 14:13:06Z yeti-dn $
  *  Copyright (C) 2004-2011 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -165,7 +165,7 @@ static GwyModuleInfo module_info = {
     N_("Imports Veeco (Digital Instruments) Nanoscope data files, "
        "version 3 or newer."),
     "Yeti <yeti@gwyddion.net>",
-    "0.28",
+    "0.29",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -304,7 +304,7 @@ nanoscope_load(const gchar *filename,
         }
         if (!gwy_stramong(self, "Ciao image list", "AFM image list",
                           "STM image list", "NCAFM image list",
-                          "Ciao force image list", NULL))
+                          "Ciao force image list", "Image list", NULL))
             continue;
 
         if (file_type == NANOSCOPE_FILE_TYPE_FORCE_BIN) {
