@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: nt-mdt.c 12576 2011-07-11 14:51:57Z yeti-dn $
+ *  @(#) $Id: nt-mdt.c 13326 2012-03-13 07:33:55Z dn2010 $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
-/* TODO: some metadata, ... */
+/* TODO: some metadata, Raman MDA images, ... */
 
 /**
  * [FILE-MAGIC-FREEDESKTOP]
@@ -752,9 +752,9 @@ mdt_load(const gchar *filename,
             if (sdframe->title) {
                 g_string_append(key, "/title");
                 gwy_container_set_string_by_name(data, key->str,
-                        g_strdup_printf("%.*s (%u)",
-                                        sdframe->title_len,
+                                        g_strdup_printf("%s (%u)",
                                         sdframe->title, i+1));
+                g_free((gpointer)sdframe->title);
             }
             else
                 gwy_app_channel_title_fall_back(data, n);
@@ -781,9 +781,9 @@ mdt_load(const gchar *filename,
                 if (mdaframe->title) {
                     g_string_append(key, "/title");
                     gwy_container_set_string_by_name(data, key->str,
-                            g_strdup_printf("%.*s (%u)",
-                                            mdaframe->title_len,
+                                            g_strdup_printf("%s (%u)",
                                             mdaframe->title, i+1));
+                    g_free((gpointer)mdaframe->title);
                 }
                 else
                     gwy_app_channel_title_fall_back(data, n);
@@ -810,9 +810,9 @@ mdt_load(const gchar *filename,
                 if (mdaframe->title) {
                     g_string_append(key, "/title");
                     gwy_container_set_string_by_name(data, key->str,
-                            g_strdup_printf("%.*s (%u)",
-                                            mdaframe->title_len,
+                                            g_strdup_printf("%s (%u)",
                                             mdaframe->title, i+1));
+                    g_free((gpointer)mdaframe->title);
                 }
                 else
                     gwy_app_channel_title_fall_back(data, n);
@@ -1127,7 +1127,8 @@ mdt_scanned_data_vars(const guchar *p,
         frame->title_len = gwy_get_guint32_le(&p);
         if (frame->title_len
             && (guint)(frame_size - (p - fstart)) >= frame->title_len) {
-            frame->title = p;
+            frame->title = g_convert((const gchar*)p, frame->title_len,
+                                    "UTF-8", "cp1251", NULL, NULL, NULL);
             p += frame->title_len;
             gwy_debug("title = <%.*s>", frame->title_len, frame->title);
         }
@@ -1266,7 +1267,8 @@ mdt_mda_vars(const guchar *p,
     frame->title_len = NameSize;
 
     if (NameSize && (guint)(frame_size - (p - fstart)) >= NameSize) {
-        frame->title = p;
+        frame->title = g_convert((const gchar*)p, frame->title_len,
+                                 "UTF-8", "cp1251", NULL, NULL, NULL);
         p += NameSize;
     }
     else
@@ -1518,7 +1520,6 @@ static GwyGraphModel* extract_scanned_spectrum (MDTScannedDataFrame *dataframe,
     const gint16 *p;
     const gchar *unit;
     gchar *framename;
-
     unit = gwy_flat_enum_to_string(dataframe->x_scale.unit,
                                    G_N_ELEMENTS(mdt_units),
                                    mdt_units, mdt_units_name);
@@ -1534,10 +1535,9 @@ static GwyGraphModel* extract_scanned_spectrum (MDTScannedDataFrame *dataframe,
     siunitz = gwy_si_unit_new_parse(unit, &power10z);
     zscale = pow10(power10z)*dataframe->z_scale.step;
 
-    if (dataframe->title_len && dataframe->title)
-        framename = g_strdup_printf("%.*s (%u)",
-                                    dataframe->title_len,
-                                    dataframe->title, number);
+    if (dataframe->title_len && dataframe->title) {
+        framename = g_strdup_printf("%s (%u)", dataframe->title, number);
+    }
     else
         framename = g_strdup_printf("Unknown spectrum (%d)", number);
 
@@ -1674,10 +1674,9 @@ static GwySpectra* extract_sps_curve (MDTScannedDataFrame *dataframe,
                     coordinates[i_p].coordy*pow10(power10coordxy));
     }
 
-    if (dataframe->title_len && dataframe->title)
-        framename = g_strdup_printf("%.*s (%u)",
-                                    dataframe->title_len,
-                                    dataframe->title, number);
+    if (dataframe->title_len && dataframe->title) {
+        framename = g_strdup_printf("%s (%u)", dataframe->title, number);
+    }
     else
         framename = g_strdup_printf("Unknown spectrum (%d)", number);
     gwy_spectra_set_title(spectra, framename);
@@ -1907,10 +1906,10 @@ extract_mda_spectrum(MDTMDAFrame *dataframe, guint number)
     MDTXMLParams params;
     GError *err = NULL;
 
-    if (dataframe->title_len && dataframe->title)
-        framename = g_strdup_printf("%.*s (%u)",
-                                    dataframe->title_len,
+    if (dataframe->title_len && dataframe->title) {
+        framename = g_strdup_printf("%s (%u)",
                                     dataframe->title, number);
+    }
     else
         framename = g_strdup_printf("Unknown spectrum (%d)", number);
 
