@@ -1,5 +1,5 @@
 /*
- *  $Id: wipfile.c 13293 2012-02-05 16:32:07Z dn2010 $
+ *  $Id: wipfile.c 13437 2012-05-10 18:25:30Z dn2010 $
  *  Copyright (C) 2010-2011 David Necas (Yeti), Petr Klapetek,
  *  Daniil Bratashov (dn2010)
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
@@ -19,12 +19,7 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-/* Warning: spectroscopy xaxis is slightly wrong (less than 1 nm near
- * edges), gamma seems to be some angle (it is near angle between
- * incident and diffracted light) and not taken into account.
- *
- * I need an example of AFM data to implement reading of datafields.
- *
+/*
  * There should be some generic infrastructure for N*M arrays of
  * spectroscopy data, same for this, NTMDT and some other formats.
  *
@@ -145,7 +140,7 @@ typedef struct {
     gdouble  polynom [3]; /* polynomial coeffs. should be zeros */
     gdouble  nc; /* central pixel number */
     gdouble  lambdac; /* central pixel lambda in nm */
-    gdouble  gamma; /* FIXME: don't know what is it */
+    gdouble  gamma; /* angle between incident and diffracted light */
     gdouble  delta; /* CCD inclination */
     gdouble  m; /* diffraction order */
     gdouble  d; /* 1e6/lines per mm */
@@ -262,6 +257,8 @@ static gdouble       wip_pixel_to_lambda       (gint i,
                                        WIPSpectralTransform *transform);
 static GwyGraphModel*
                      wip_read_graph            (GNode *node);
+static void          wip_flip_xy               (GwyDataField *source,
+                                                GwyDataField *dest);
 static GwyDataField *
                      wip_read_image            (GNode *node);
 static GwyDataField *
@@ -274,7 +271,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports WItec Project data files."),
     "dn2010 <dn2010@gmail.com>",
-    "0.2",
+    "0.3",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov",
     "2010",
 };
@@ -705,26 +702,35 @@ static GwyDataField * wip_read_bmp(const guchar *bmpdata,
     return dfield;
 }
 
+/* spectral transform from here:
+ * http://www.horiba.com/us/en/scientific/products/optics-tutorial/wavelength-pixel-position/
+ */
 static gdouble wip_pixel_to_lambda(gint i,
                                    WIPSpectralTransform *transform)
 {
-    gdouble lambda, x, a2, alpha, alpha0;
+    gdouble lambda, alpha, betac, hc, lh, hi, betah, betai;
 
-    if ((transform->lambdac/transform->d) < 0.0
-     || (transform->lambdac/transform->d) > 1.0)
+    if ((transform->d == 0.0) || (transform->m == 0.0)
+     || (cos(transform->gamma / 2.0) == 0.0)
+     || (transform->lambdac * transform->m / transform->d / 2.0
+       / cos(transform->gamma / 2.0) > 1.0)
+     || (transform->lambdac * transform->m / transform->d / 2.0
+       / cos(transform->gamma / 2.0) < -1.0))
         return i;
-    alpha0 = asin(transform->lambdac * transform->m / transform->d);
-    x = (i - transform->nc + 1) * transform->x;
-    a2 = transform->f * transform->f + x * x
-       - 2 * transform->f * x * cos(M_PI/2.0 + transform->delta);
-    if ((a2 < 0.0) || (x/sqrt(a2)*sin(M_PI/2 + transform->delta)) > 1)
+    alpha = asin(transform->lambdac * transform->m / transform->d / 2.0
+               / cos(transform->gamma / 2.0)) - transform->gamma / 2.0;
+    betac = transform->gamma + alpha;
+    hc = transform->f * sin(transform->delta);
+    lh = transform->f * cos(transform->delta);
+    hi = transform->x * (transform->nc - i) + hc;
+    betah = betac + transform->delta;
+    if (lh == 0.0)
         return i;
-    alpha = asin(x / sqrt(a2) * sin(M_PI/2 + transform->delta));
-    lambda = transform->d / transform->m * sin(alpha0 + alpha);
+    betai = betah - atan(hi / lh);
+    lambda = transform->d / transform->m * (sin(alpha) + sin(betai));
 
     return lambda;
 }
-
 static GwyGraphModel * wip_read_graph(GNode *node)
 {
     WIPGraph *header;
@@ -854,13 +860,35 @@ static GwyGraphModel * wip_read_graph(GNode *node)
     return gmodel;
 }
 
+static void wip_flip_xy(GwyDataField *source, GwyDataField *dest)
+{
+    gint xres, yres, i, j;
+    gdouble *dd;
+    const gdouble *sd;
+
+    xres = gwy_data_field_get_xres(source);
+    yres = gwy_data_field_get_yres(source);
+    gwy_data_field_resample(dest, yres, xres, GWY_INTERPOLATION_NONE);
+    sd = gwy_data_field_get_data_const(source);
+    dd = gwy_data_field_get_data(dest);
+
+    for (i = 0; i < xres; i++) {
+        for (j = 0; j < yres; j++) {
+            dd[i*yres + (yres - 1 - j)] = sd[j*xres + i];
+        }
+    }
+
+    gwy_data_field_set_xreal(dest, gwy_data_field_get_yreal(source));
+    gwy_data_field_set_yreal(dest, gwy_data_field_get_xreal(source));
+}
+
 static GwyDataField * wip_read_image(GNode *node)
 {
     WIPImage *header;
     WIPAxis *zaxis;
     WIPSpaceTransform *xyaxis;
     WIPIdNode *idnode;
-    GwyDataField *dfield;
+    GwyDataField *dfield, *dfield2;
     GwySIUnit *siunitxy, *siunitz;
     gdouble *data;
     gdouble xscale, yscale, zscale;
@@ -937,17 +965,14 @@ static GwyDataField * wip_read_image(GNode *node)
     g_free(idnode);
 
     // Reading actual data
-    /* FIXME: data is stored in strange way in TDImage, so it is more
-     * simple to swap X and Y axes here to read them correctly */
-    dfield = gwy_data_field_new(header->sizey, header->sizex,
+    /* data is stored in strange way in TDImage, so it is more
+     * simple to swap X and Y axes here to read them correctly
+     * and rotate datafield in the end of procedure */
+    dfield2 = gwy_data_field_new(header->sizey, header->sizex,
                           header->sizey * pow(10.0, power10xy) * yscale,
                           header->sizex * pow(10.0, power10xy) * xscale,
                           FALSE);
-    data = gwy_data_field_get_data(dfield);
-    gwy_data_field_set_si_unit_z(dfield, siunitz);
-    gwy_data_field_set_si_unit_xy(dfield, siunitxy);
-    g_object_unref(siunitz);
-    g_object_unref(siunitxy);
+    data = gwy_data_field_get_data(dfield2);
 
     zscale = pow(10.0, power10z);
     if (zscale == 0.0)
@@ -1006,8 +1031,20 @@ static GwyDataField * wip_read_image(GNode *node)
             g_warning("Wrong datatype");
     }
 
-    if (mirrory || mirrorx) {
-        gwy_data_field_invert(dfield, mirrory, mirrorx, FALSE);
+    dfield = gwy_data_field_new(header->sizex, header->sizey,
+                          header->sizex * pow(10.0, power10xy) * xscale,
+                          header->sizey * pow(10.0, power10xy) * yscale,
+                          FALSE);
+    wip_flip_xy(dfield2, dfield);
+    g_object_unref(dfield2);
+
+    gwy_data_field_set_si_unit_z(dfield, siunitz);
+    gwy_data_field_set_si_unit_xy(dfield, siunitxy);
+    g_object_unref(siunitz);
+    g_object_unref(siunitxy);
+
+    if (mirrorx || mirrory) {
+        gwy_data_field_invert(dfield, mirrorx, mirrory, FALSE);
     }
 
     return dfield;
